@@ -1,3 +1,7 @@
+set_state_inspector(function() {
+  dir(".")
+})
+
 expect_no_output <- function(...) {
   testthat::expect_output(..., regexp = NA)
 }
@@ -38,10 +42,15 @@ skip_if_cannot_knit <- function() {
   skip_if(!rmarkdown::pandoc_available())
 }
 
-# Need to also specify `LC_ALL` because `LANGUAGE` is ignored when
-# `LANG` is set (here via `LC_ALL`) to `C` or `C.UTF-8`
-with_lang <- function(lc, language, expr) {
-  withr::local_envvar(c(LC_ALL = lc))
-  withr::local_language(language)
-  expr
+# Used to skip tests that will fail when locale is set to C, for
+# instance `with_language()` tests. These tests should only be run
+# when using a locale like `en_US`.
+skip_if_c_locale <- function() {
+  lc_all <- Sys.getenv("LC_ALL", "")
+  skip_if(lc_all %in% c("C", "C.UTF-8"))
+
+  if (lc_all == "") {
+    lang <- Sys.getenv("LANG", "")
+    skip_if(lang %in% c("C", "C.UTF-8"))
+  }
 }
